Class: Phoebe::Models::Data::Observations::Geo::Recent::NotableListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb

Overview

Defined Under Namespace

Modules: Detail

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(lat:, lng:, back: nil, detail: nil, dist: nil, hotspot: nil, max_results: nil, spp_locale: nil, request_options: {}) ⇒ Object

Parameters:

  • lat (Float)
  • lng (Float)
  • back (Integer) (defaults to: nil)

    The number of days back to fetch observations.

  • detail (Symbol, Phoebe::Models::Data::Observations::Geo::Recent::NotableListParams::Detail) (defaults to: nil)

    Include a subset (simple), or all (full), of the fields available.

  • dist (Integer) (defaults to: nil)

    The search radius from the given position, in kilometers.

  • hotspot (Boolean) (defaults to: nil)

    Only fetch observations from hotspots

  • max_results (Integer) (defaults to: nil)

    Only fetch this number of observations

  • spp_locale (String) (defaults to: nil)

    Use this language for species common names

  • request_options (Phoebe::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 60

Instance Attribute Details

#backInteger?

The number of days back to fetch observations.

Returns:

  • (Integer, nil)


28
# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 28

optional :back, Integer

#detailSymbol, ...

Include a subset (simple), or all (full), of the fields available.



34
# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 34

optional :detail, enum: -> { Phoebe::Data::Observations::Geo::Recent::NotableListParams::Detail }

#distInteger?

The search radius from the given position, in kilometers.

Returns:

  • (Integer, nil)


40
# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 40

optional :dist, Integer

#hotspotBoolean?

Only fetch observations from hotspots

Returns:

  • (Boolean, nil)


46
# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 46

optional :hotspot, Phoebe::Internal::Type::Boolean

#latFloat

Returns:

  • (Float)


17
# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 17

required :lat, Float

#lngFloat

Returns:

  • (Float)


22
# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 22

required :lng, Float

#max_resultsInteger?

Only fetch this number of observations

Returns:

  • (Integer, nil)


52
# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 52

optional :max_results, Integer

#spp_localeString?

Use this language for species common names

Returns:

  • (String, nil)


58
# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 58

optional :spp_locale, String