Class: Phoebe::Models::Data::Observations::Geo::Recent::SpecieListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Phoebe::Models::Data::Observations::Geo::Recent::SpecieListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/phoebe/models/data/observations/geo/recent/specie_list_params.rb
Overview
Instance Attribute Summary collapse
-
#back ⇒ Integer?
The number of days back to fetch observations.
-
#dist ⇒ Integer?
The search radius from the given position, in kilometers.
-
#hotspot ⇒ Boolean?
Only fetch observations from hotspots.
-
#include_provisional ⇒ Boolean?
Include observations which have not yet been reviewed.
- #lat ⇒ Float
- #lng ⇒ Float
-
#max_results ⇒ Integer?
Only fetch this number of observations.
- #species_code ⇒ String
-
#spp_locale ⇒ String?
Use this language for species common names.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(species_code:, lat:, lng:, back: nil, dist: nil, hotspot: nil, include_provisional: nil, max_results: nil, spp_locale: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/phoebe/models/data/observations/geo/recent/specie_list_params.rb', line 65
|
Instance Attribute Details
#back ⇒ Integer?
The number of days back to fetch observations.
33 |
# File 'lib/phoebe/models/data/observations/geo/recent/specie_list_params.rb', line 33 optional :back, Integer |
#dist ⇒ Integer?
The search radius from the given position, in kilometers.
39 |
# File 'lib/phoebe/models/data/observations/geo/recent/specie_list_params.rb', line 39 optional :dist, Integer |
#hotspot ⇒ Boolean?
Only fetch observations from hotspots
45 |
# File 'lib/phoebe/models/data/observations/geo/recent/specie_list_params.rb', line 45 optional :hotspot, Phoebe::Internal::Type::Boolean |
#include_provisional ⇒ Boolean?
Include observations which have not yet been reviewed.
51 |
# File 'lib/phoebe/models/data/observations/geo/recent/specie_list_params.rb', line 51 optional :include_provisional, Phoebe::Internal::Type::Boolean |
#lat ⇒ Float
22 |
# File 'lib/phoebe/models/data/observations/geo/recent/specie_list_params.rb', line 22 required :lat, Float |
#lng ⇒ Float
27 |
# File 'lib/phoebe/models/data/observations/geo/recent/specie_list_params.rb', line 27 required :lng, Float |
#max_results ⇒ Integer?
Only fetch this number of observations
57 |
# File 'lib/phoebe/models/data/observations/geo/recent/specie_list_params.rb', line 57 optional :max_results, Integer |
#species_code ⇒ String
17 |
# File 'lib/phoebe/models/data/observations/geo/recent/specie_list_params.rb', line 17 required :species_code, String |
#spp_locale ⇒ String?
Use this language for species common names
63 |
# File 'lib/phoebe/models/data/observations/geo/recent/specie_list_params.rb', line 63 optional :spp_locale, String |