Class: Phoebe::Models::Data::Observations::Geo::RecentListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/phoebe/models/data/observations/geo/recent_list_params.rb

Overview

Defined Under Namespace

Modules: Cat, Sort

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(lat:, lng:, back: nil, cat: nil, dist: nil, hotspot: nil, include_provisional: nil, max_results: nil, sort: nil, spp_locale: nil, request_options: {}) ⇒ Object

Parameters:

  • lat (Float)
  • lng (Float)
  • back (Integer) (defaults to: nil)

    The number of days back to fetch observations.

  • cat (Symbol, Phoebe::Models::Data::Observations::Geo::RecentListParams::Cat) (defaults to: nil)

    Only fetch observations from these taxonomic categories

  • dist (Integer) (defaults to: nil)

    The search radius from the given position, in kilometers.

  • hotspot (Boolean) (defaults to: nil)

    Only fetch observations from hotspots

  • include_provisional (Boolean) (defaults to: nil)

    Include observations which have not yet been reviewed.

  • max_results (Integer) (defaults to: nil)

    Only fetch this number of observations

  • sort (Symbol, Phoebe::Models::Data::Observations::Geo::RecentListParams::Sort) (defaults to: nil)

    Sort observations by taxonomy or by date, most recent first.

  • spp_locale (String) (defaults to: nil)

    Use this language for species common names

  • request_options (Phoebe::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 71

Instance Attribute Details

#backInteger?

The number of days back to fetch observations.

Returns:

  • (Integer, nil)


27
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 27

optional :back, Integer

#catSymbol, ...

Only fetch observations from these taxonomic categories



33
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 33

optional :cat, enum: -> { Phoebe::Data::Observations::Geo::RecentListParams::Cat }

#distInteger?

The search radius from the given position, in kilometers.

Returns:

  • (Integer, nil)


39
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 39

optional :dist, Integer

#hotspotBoolean?

Only fetch observations from hotspots

Returns:

  • (Boolean, nil)


45
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 45

optional :hotspot, Phoebe::Internal::Type::Boolean

#include_provisionalBoolean?

Include observations which have not yet been reviewed.

Returns:

  • (Boolean, nil)


51
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 51

optional :include_provisional, Phoebe::Internal::Type::Boolean

#latFloat

Returns:

  • (Float)


16
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 16

required :lat, Float

#lngFloat

Returns:

  • (Float)


21
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 21

required :lng, Float

#max_resultsInteger?

Only fetch this number of observations

Returns:

  • (Integer, nil)


57
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 57

optional :max_results, Integer

#sortSymbol, ...

Sort observations by taxonomy or by date, most recent first.



63
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 63

optional :sort, enum: -> { Phoebe::Data::Observations::Geo::RecentListParams::Sort }

#spp_localeString?

Use this language for species common names

Returns:

  • (String, nil)


69
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 69

optional :spp_locale, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 107