Class: Phoebe::Models::Data::Observations::Nearest::GeoSpecieListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(species_code:, lat:, lng:, back: nil, dist: nil, hotspot: nil, include_provisional: nil, max_results: nil, spp_locale: nil, request_options: {}) ⇒ Object

Parameters:

  • species_code (String)
  • lat (Float)
  • lng (Float)
  • back (Integer) (defaults to: nil)

    The number of days back to fetch observations.

  • dist (Integer) (defaults to: nil)

    Only fetch observations within this distance of the provided lat/lng

  • hotspot (Boolean) (defaults to: nil)

    Only fetch observations from hotspots

  • include_provisional (Boolean) (defaults to: nil)

    Include observations which have not yet been reviewed.

  • max_results (Integer) (defaults to: nil)

    Only fetch up to this number of observations

  • spp_locale (String) (defaults to: nil)

    Use this language for species common names

  • request_options (Phoebe::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 64

Instance Attribute Details

#backInteger?

The number of days back to fetch observations.

Returns:

  • (Integer, nil)


32
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 32

optional :back, Integer

#distInteger?

Only fetch observations within this distance of the provided lat/lng

Returns:

  • (Integer, nil)


38
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 38

optional :dist, Integer

#hotspotBoolean?

Only fetch observations from hotspots

Returns:

  • (Boolean, nil)


44
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 44

optional :hotspot, Phoebe::Internal::Type::Boolean

#include_provisionalBoolean?

Include observations which have not yet been reviewed.

Returns:

  • (Boolean, nil)


50
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 50

optional :include_provisional, Phoebe::Internal::Type::Boolean

#latFloat

Returns:

  • (Float)


21
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 21

required :lat, Float

#lngFloat

Returns:

  • (Float)


26
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 26

required :lng, Float

#max_resultsInteger?

Only fetch up to this number of observations

Returns:

  • (Integer, nil)


56
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 56

optional :max_results, Integer

#species_codeString

Returns:

  • (String)


16
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 16

required :species_code, String

#spp_localeString?

Use this language for species common names

Returns:

  • (String, nil)


62
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 62

optional :spp_locale, String