Class: Phoebe::Models::Data::Observations::Recent::HistoricListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Phoebe::Models::Data::Observations::Recent::HistoricListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/phoebe/models/data/observations/recent/historic_list_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#cat ⇒ Symbol, ...
Only fetch observations from these taxonomic categories.
- #d ⇒ Integer
-
#detail ⇒ Symbol, ...
Include a subset (simple), or all (full), of the fields available.
-
#hotspot ⇒ Boolean?
Only fetch observations from hotspots.
-
#include_provisional ⇒ Boolean?
Include observations which have not yet been reviewed.
- #m ⇒ Integer
-
#max_results ⇒ Integer?
Only fetch this number of observations.
-
#r ⇒ Array<String>?
Fetch observations from up to 50 locations.
-
#rank ⇒ Symbol, ...
Include latest observation of the day, or the first added.
- #region_code ⇒ String
-
#spp_locale ⇒ String?
Use this language for species common names.
- #y_ ⇒ Integer
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(region_code:, y_:, m:, d:, cat: nil, detail: nil, hotspot: nil, include_provisional: nil, max_results: nil, r: nil, rank: nil, spp_locale: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/phoebe/models/data/observations/recent/historic_list_params.rb', line 81
|
Instance Attribute Details
#cat ⇒ Symbol, ...
Only fetch observations from these taxonomic categories
37 |
# File 'lib/phoebe/models/data/observations/recent/historic_list_params.rb', line 37 optional :cat, enum: -> { Phoebe::Data::Observations::Recent::HistoricListParams::Cat } |
#d ⇒ Integer
31 |
# File 'lib/phoebe/models/data/observations/recent/historic_list_params.rb', line 31 required :d, Integer |
#detail ⇒ Symbol, ...
Include a subset (simple), or all (full), of the fields available.
43 |
# File 'lib/phoebe/models/data/observations/recent/historic_list_params.rb', line 43 optional :detail, enum: -> { Phoebe::Data::Observations::Recent::HistoricListParams::Detail } |
#hotspot ⇒ Boolean?
Only fetch observations from hotspots
49 |
# File 'lib/phoebe/models/data/observations/recent/historic_list_params.rb', line 49 optional :hotspot, Phoebe::Internal::Type::Boolean |
#include_provisional ⇒ Boolean?
Include observations which have not yet been reviewed.
55 |
# File 'lib/phoebe/models/data/observations/recent/historic_list_params.rb', line 55 optional :include_provisional, Phoebe::Internal::Type::Boolean |
#m ⇒ Integer
26 |
# File 'lib/phoebe/models/data/observations/recent/historic_list_params.rb', line 26 required :m, Integer |
#max_results ⇒ Integer?
Only fetch this number of observations
61 |
# File 'lib/phoebe/models/data/observations/recent/historic_list_params.rb', line 61 optional :max_results, Integer |
#r ⇒ Array<String>?
Fetch observations from up to 50 locations
67 |
# File 'lib/phoebe/models/data/observations/recent/historic_list_params.rb', line 67 optional :r, Phoebe::Internal::Type::ArrayOf[String] |
#rank ⇒ Symbol, ...
Include latest observation of the day, or the first added
73 |
# File 'lib/phoebe/models/data/observations/recent/historic_list_params.rb', line 73 optional :rank, enum: -> { Phoebe::Data::Observations::Recent::HistoricListParams::Rank } |
#region_code ⇒ String
16 |
# File 'lib/phoebe/models/data/observations/recent/historic_list_params.rb', line 16 required :region_code, String |
#spp_locale ⇒ String?
Use this language for species common names
79 |
# File 'lib/phoebe/models/data/observations/recent/historic_list_params.rb', line 79 optional :spp_locale, String |
#y_ ⇒ Integer
21 |
# File 'lib/phoebe/models/data/observations/recent/historic_list_params.rb', line 21 required :y_, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/phoebe/models/data/observations/recent/historic_list_params.rb', line 121
|