Class: Phoebe::Models::Product::Lists::HistoricalRetrieveParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Phoebe::Models::Product::Lists::HistoricalRetrieveParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/phoebe/models/product/lists/historical_retrieve_params.rb
Overview
Defined Under Namespace
Modules: SortKey
Instance Attribute Summary collapse
- #d ⇒ Integer
- #m ⇒ Integer
-
#max_results ⇒ Integer?
Only fetch this number of checklists.
- #region_code ⇒ String
-
#sort_key ⇒ Symbol, ...
Order the results by the date of the checklist or by the date it was submitted.
- #y_ ⇒ Integer
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(region_code:, y_:, m:, d:, max_results: nil, sort_key: nil, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(region_code:, y_:, m:, d:, max_results: nil, sort_key: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/phoebe/models/product/lists/historical_retrieve_params.rb', line 44
|
Instance Attribute Details
#d ⇒ Integer
30 |
# File 'lib/phoebe/models/product/lists/historical_retrieve_params.rb', line 30 required :d, Integer |
#m ⇒ Integer
25 |
# File 'lib/phoebe/models/product/lists/historical_retrieve_params.rb', line 25 required :m, Integer |
#max_results ⇒ Integer?
Only fetch this number of checklists.
36 |
# File 'lib/phoebe/models/product/lists/historical_retrieve_params.rb', line 36 optional :max_results, Integer |
#region_code ⇒ String
15 |
# File 'lib/phoebe/models/product/lists/historical_retrieve_params.rb', line 15 required :region_code, String |
#sort_key ⇒ Symbol, ...
Order the results by the date of the checklist or by the date it was submitted.
42 |
# File 'lib/phoebe/models/product/lists/historical_retrieve_params.rb', line 42 optional :sort_key, enum: -> { Phoebe::Product::Lists::HistoricalRetrieveParams::SortKey } |
#y_ ⇒ Integer
20 |
# File 'lib/phoebe/models/product/lists/historical_retrieve_params.rb', line 20 required :y_, Integer |