Class: Phoebe::Models::Ref::Hotspot::GeoRetrieveParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Phoebe::Models::Ref::Hotspot::GeoRetrieveParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/phoebe/models/ref/hotspot/geo_retrieve_params.rb
Overview
Defined Under Namespace
Modules: Fmt
Instance Attribute Summary collapse
-
#back ⇒ Integer?
The number of days back to fetch hotspots.
-
#dist ⇒ Integer?
The search radius from the given position, in kilometers.
-
#fmt ⇒ Symbol, ...
Fetch the records in CSV or JSON format.
- #lat ⇒ Float
- #lng ⇒ Float
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(lat:, lng:, back: nil, dist: nil, fmt: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/phoebe/models/ref/hotspot/geo_retrieve_params.rb', line 40
|
Instance Attribute Details
#back ⇒ Integer?
The number of days back to fetch hotspots.
26 |
# File 'lib/phoebe/models/ref/hotspot/geo_retrieve_params.rb', line 26 optional :back, Integer |
#dist ⇒ Integer?
The search radius from the given position, in kilometers.
32 |
# File 'lib/phoebe/models/ref/hotspot/geo_retrieve_params.rb', line 32 optional :dist, Integer |
#fmt ⇒ Symbol, ...
Fetch the records in CSV or JSON format.
38 |
# File 'lib/phoebe/models/ref/hotspot/geo_retrieve_params.rb', line 38 optional :fmt, enum: -> { Phoebe::Ref::Hotspot::GeoRetrieveParams::Fmt } |
#lat ⇒ Float
15 |
# File 'lib/phoebe/models/ref/hotspot/geo_retrieve_params.rb', line 15 required :lat, Float |
#lng ⇒ Float
20 |
# File 'lib/phoebe/models/ref/hotspot/geo_retrieve_params.rb', line 20 required :lng, Float |