Class: Phoebe::Resources::Data::Observations

Inherits:
Object
  • Object
show all
Defined in:
lib/phoebe/resources/data/observations.rb,
lib/phoebe/resources/data/observations/geo.rb,
lib/phoebe/resources/data/observations/recent.rb,
lib/phoebe/resources/data/observations/nearest.rb,
lib/phoebe/resources/data/observations/geo/recent.rb,
lib/phoebe/resources/data/observations/recent/notable.rb,
lib/phoebe/resources/data/observations/recent/species.rb,
lib/phoebe/resources/data/observations/recent/historic.rb,
lib/phoebe/resources/data/observations/geo/recent/notable.rb,
lib/phoebe/resources/data/observations/geo/recent/species.rb,
lib/phoebe/resources/data/observations/nearest/geo_species.rb

Defined Under Namespace

Classes: Geo, Nearest, Recent

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Observations

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Observations.

Parameters:



24
25
26
27
28
29
# File 'lib/phoebe/resources/data/observations.rb', line 24

def initialize(client:)
  @client = client
  @recent = Phoebe::Resources::Data::Observations::Recent.new(client: client)
  @geo = Phoebe::Resources::Data::Observations::Geo.new(client: client)
  @nearest = Phoebe::Resources::Data::Observations::Nearest.new(client: client)
end

Instance Attribute Details

#geoPhoebe::Resources::Data::Observations::Geo (readonly)



16
17
18
# File 'lib/phoebe/resources/data/observations.rb', line 16

def geo
  @geo
end

#nearestPhoebe::Resources::Data::Observations::Nearest (readonly)



19
20
21
# File 'lib/phoebe/resources/data/observations.rb', line 19

def nearest
  @nearest
end

#recentPhoebe::Resources::Data::Observations::Recent (readonly)

The data/obs end-points are used to fetch observations submitted to eBird in checklists. There are two categories of end-point: 1. Fetch observations for a specific country, region or location. 2. Fetch observations for nearby locations - up to a distance of 50km. Each end-point supports optional query parameters which allow you to filter the list of observations returned.



13
14
15
# File 'lib/phoebe/resources/data/observations.rb', line 13

def recent
  @recent
end