Class: Phoebe::Resources::Product

Inherits:
Object
  • Object
show all
Defined in:
lib/phoebe/resources/product.rb,
lib/phoebe/resources/product/lists.rb,
lib/phoebe/resources/product/stats.rb,
lib/phoebe/resources/product/top100.rb,
lib/phoebe/resources/product/checklist.rb,
lib/phoebe/resources/product/species_list.rb,
lib/phoebe/resources/product/lists/historical.rb

Defined Under Namespace

Classes: Checklist, Lists, SpeciesList, Stats, Top100

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Product

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Product.

Parameters:



49
50
51
52
53
54
55
56
# File 'lib/phoebe/resources/product.rb', line 49

def initialize(client:)
  @client = client
  @lists = Phoebe::Resources::Product::Lists.new(client: client)
  @top100 = Phoebe::Resources::Product::Top100.new(client: client)
  @stats = Phoebe::Resources::Product::Stats.new(client: client)
  @species_list = Phoebe::Resources::Product::SpeciesList.new(client: client)
  @checklist = Phoebe::Resources::Product::Checklist.new(client: client)
end

Instance Attribute Details

#checklistPhoebe::Resources::Product::Checklist (readonly)

The product end-points make it easy to get the information shown in various pages on the eBird web site: 1. The Top 100 contributors on a given date. 2. The checklists submitted on a given date. 3. The most recent checklists submitted. 4. A summary of the checklists submitted on a given date. 5. The details and all the observations of a checklist.



44
45
46
# File 'lib/phoebe/resources/product.rb', line 44

def checklist
  @checklist
end

#listsPhoebe::Resources::Product::Lists (readonly)

The data/obs end-points are used to fetch observations submitted to eBird in checklists. There are two categories of end-point: 1. Fetch observations for a specific country, region or location. 2. Fetch observations for nearby locations - up to a distance of 50km. Each end-point supports optional query parameters which allow you to filter the list of observations returned.



12
13
14
# File 'lib/phoebe/resources/product.rb', line 12

def lists
  @lists
end

#species_listPhoebe::Resources::Product::SpeciesList (readonly)

The product end-points make it easy to get the information shown in various pages on the eBird web site: 1. The Top 100 contributors on a given date. 2. The checklists submitted on a given date. 3. The most recent checklists submitted. 4. A summary of the checklists submitted on a given date. 5. The details and all the observations of a checklist.



36
37
38
# File 'lib/phoebe/resources/product.rb', line 36

def species_list
  @species_list
end

#statsPhoebe::Resources::Product::Stats (readonly)

The product end-points make it easy to get the information shown in various pages on the eBird web site: 1. The Top 100 contributors on a given date. 2. The checklists submitted on a given date. 3. The most recent checklists submitted. 4. A summary of the checklists submitted on a given date. 5. The details and all the observations of a checklist.



28
29
30
# File 'lib/phoebe/resources/product.rb', line 28

def stats
  @stats
end

#top100Phoebe::Resources::Product::Top100 (readonly)

The product end-points make it easy to get the information shown in various pages on the eBird web site: 1. The Top 100 contributors on a given date. 2. The checklists submitted on a given date. 3. The most recent checklists submitted. 4. A summary of the checklists submitted on a given date. 5. The details and all the observations of a checklist.



20
21
22
# File 'lib/phoebe/resources/product.rb', line 20

def top100
  @top100
end