Class: Phoebe::Resources::Ref
- Inherits:
-
Object
- Object
- Phoebe::Resources::Ref
- Defined in:
- lib/phoebe/resources/ref.rb,
lib/phoebe/resources/ref/region.rb,
lib/phoebe/resources/ref/hotspot.rb,
lib/phoebe/resources/ref/taxonomy.rb,
lib/phoebe/resources/ref/hotspot/geo.rb,
lib/phoebe/resources/ref/region/info.rb,
lib/phoebe/resources/ref/region/list.rb,
lib/phoebe/resources/ref/hotspot/info.rb,
lib/phoebe/resources/ref/taxonomy/ebird.rb,
lib/phoebe/resources/ref/taxonomy/forms.rb,
lib/phoebe/resources/ref/region/adjacent.rb,
lib/phoebe/resources/ref/taxonomy/locales.rb,
lib/phoebe/resources/ref/taxonomy/versions.rb,
lib/phoebe/resources/ref/taxonomy/species_groups.rb
Defined Under Namespace
Classes: Hotspot, Region, Taxonomy
Instance Attribute Summary collapse
-
#hotspot ⇒ Phoebe::Resources::Ref::Hotspot
readonly
With the ref/hotspot end-points you can find the hotspots for a given country or region or nearby hotspots.
- #region ⇒ Phoebe::Resources::Ref::Region readonly
- #taxonomy ⇒ Phoebe::Resources::Ref::Taxonomy readonly
Instance Method Summary collapse
-
#initialize(client:) ⇒ Ref
constructor
private
A new instance of Ref.
Constructor Details
#initialize(client:) ⇒ Ref
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Ref.
20 21 22 23 24 25 |
# File 'lib/phoebe/resources/ref.rb', line 20 def initialize(client:) @client = client @region = Phoebe::Resources::Ref::Region.new(client: client) @hotspot = Phoebe::Resources::Ref::Hotspot.new(client: client) @taxonomy = Phoebe::Resources::Ref::Taxonomy.new(client: client) end |
Instance Attribute Details
#hotspot ⇒ Phoebe::Resources::Ref::Hotspot (readonly)
With the ref/hotspot end-points you can find the hotspots for a given country or region or nearby hotspots
12 13 14 |
# File 'lib/phoebe/resources/ref.rb', line 12 def hotspot @hotspot end |
#region ⇒ Phoebe::Resources::Ref::Region (readonly)
7 8 9 |
# File 'lib/phoebe/resources/ref.rb', line 7 def region @region end |
#taxonomy ⇒ Phoebe::Resources::Ref::Taxonomy (readonly)
15 16 17 |
# File 'lib/phoebe/resources/ref.rb', line 15 def taxonomy @taxonomy end |