Class: Phoebe::Resources::Ref::Hotspot::Info

Inherits:
Object
  • Object
show all
Defined in:
lib/phoebe/resources/ref/hotspot/info.rb

Overview

With the ref/hotspot end-points you can find the hotspots for a given country or region or nearby hotspots

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Info

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Info.

Parameters:



35
36
37
# File 'lib/phoebe/resources/ref/hotspot/info.rb', line 35

def initialize(client:)
  @client = client
end

Instance Method Details

#retrieve(loc_id, request_options: {}) ⇒ Phoebe::Models::Ref::Hotspot::InfoRetrieveResponse

Get information on the location of a hotspot. #### Notes This API call only works for hotspots. If you pass the location code for a private location or an invalid location code then an HTTP 410 (Gone) error is returned.

Parameters:

Returns:

See Also:



23
24
25
26
27
28
29
30
# File 'lib/phoebe/resources/ref/hotspot/info.rb', line 23

def retrieve(loc_id, params = {})
  @client.request(
    method: :get,
    path: ["ref/hotspot/info/%1$s", loc_id],
    model: Phoebe::Models::Ref::Hotspot::InfoRetrieveResponse,
    options: params[:request_options]
  )
end