Class: Phoebe::Models::Data::Observations::Geo::Recent::NotableListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Phoebe::Models::Data::Observations::Geo::Recent::NotableListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb
Overview
Defined Under Namespace
Modules: Detail
Instance Attribute Summary collapse
-
#back ⇒ Integer?
The number of days back to fetch observations.
-
#detail ⇒ Symbol, ...
Include a subset (simple), or all (full), of the fields available.
-
#dist ⇒ Integer?
The search radius from the given position, in kilometers.
-
#hotspot ⇒ Boolean?
Only fetch observations from hotspots.
- #lat ⇒ Float
- #lng ⇒ Float
-
#max_results ⇒ Integer?
Only fetch this number of observations.
-
#spp_locale ⇒ String?
Use this language for species common names.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(lat:, lng:, back: nil, detail: nil, dist: nil, hotspot: nil, max_results: nil, spp_locale: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 60
|
Instance Attribute Details
#back ⇒ Integer?
The number of days back to fetch observations.
28 |
# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 28 optional :back, Integer |
#detail ⇒ Symbol, ...
Include a subset (simple), or all (full), of the fields available.
34 |
# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 34 optional :detail, enum: -> { Phoebe::Data::Observations::Geo::Recent::NotableListParams::Detail } |
#dist ⇒ Integer?
The search radius from the given position, in kilometers.
40 |
# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 40 optional :dist, Integer |
#hotspot ⇒ Boolean?
Only fetch observations from hotspots
46 |
# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 46 optional :hotspot, Phoebe::Internal::Type::Boolean |
#lat ⇒ Float
17 |
# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 17 required :lat, Float |
#lng ⇒ Float
22 |
# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 22 required :lng, Float |
#max_results ⇒ Integer?
Only fetch this number of observations
52 |
# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 52 optional :max_results, Integer |
#spp_locale ⇒ String?
Use this language for species common names
58 |
# File 'lib/phoebe/models/data/observations/geo/recent/notable_list_params.rb', line 58 optional :spp_locale, String |