Class: Phoebe::Models::Data::Observations::Geo::RecentListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Phoebe::Models::Data::Observations::Geo::RecentListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/phoebe/models/data/observations/geo/recent_list_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#back ⇒ Integer?
The number of days back to fetch observations.
-
#cat ⇒ Symbol, ...
Only fetch observations from these taxonomic categories.
-
#dist ⇒ Integer?
The search radius from the given position, in kilometers.
-
#hotspot ⇒ Boolean?
Only fetch observations from hotspots.
-
#include_provisional ⇒ Boolean?
Include observations which have not yet been reviewed.
- #lat ⇒ Float
- #lng ⇒ Float
-
#max_results ⇒ Integer?
Only fetch this number of observations.
-
#sort ⇒ Symbol, ...
Sort observations by taxonomy or by date, most recent first.
-
#spp_locale ⇒ String?
Use this language for species common names.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(lat:, lng:, back: nil, cat: nil, dist: nil, hotspot: nil, include_provisional: nil, max_results: nil, sort: nil, spp_locale: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 71
|
Instance Attribute Details
#back ⇒ Integer?
The number of days back to fetch observations.
27 |
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 27 optional :back, Integer |
#cat ⇒ Symbol, ...
Only fetch observations from these taxonomic categories
33 |
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 33 optional :cat, enum: -> { Phoebe::Data::Observations::Geo::RecentListParams::Cat } |
#dist ⇒ Integer?
The search radius from the given position, in kilometers.
39 |
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 39 optional :dist, Integer |
#hotspot ⇒ Boolean?
Only fetch observations from hotspots
45 |
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 45 optional :hotspot, Phoebe::Internal::Type::Boolean |
#include_provisional ⇒ Boolean?
Include observations which have not yet been reviewed.
51 |
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 51 optional :include_provisional, Phoebe::Internal::Type::Boolean |
#lat ⇒ Float
16 |
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 16 required :lat, Float |
#lng ⇒ Float
21 |
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 21 required :lng, Float |
#max_results ⇒ Integer?
Only fetch this number of observations
57 |
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 57 optional :max_results, Integer |
#sort ⇒ Symbol, ...
Sort observations by taxonomy or by date, most recent first.
63 |
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 63 optional :sort, enum: -> { Phoebe::Data::Observations::Geo::RecentListParams::Sort } |
#spp_locale ⇒ String?
Use this language for species common names
69 |
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 69 optional :spp_locale, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/phoebe/models/data/observations/geo/recent_list_params.rb', line 107
|