Class: Phoebe::Models::Data::Observations::Nearest::GeoSpecieListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Phoebe::Models::Data::Observations::Nearest::GeoSpecieListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb
Overview
Instance Attribute Summary collapse
-
#back ⇒ Integer?
The number of days back to fetch observations.
-
#dist ⇒ Integer?
Only fetch observations within this distance of the provided lat/lng.
-
#hotspot ⇒ Boolean?
Only fetch observations from hotspots.
-
#include_provisional ⇒ Boolean?
Include observations which have not yet been reviewed.
- #lat ⇒ Float
- #lng ⇒ Float
-
#max_results ⇒ Integer?
Only fetch up to this number of observations.
- #species_code ⇒ String
-
#spp_locale ⇒ String?
Use this language for species common names.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(species_code:, lat:, lng:, back: nil, dist: nil, hotspot: nil, include_provisional: nil, max_results: nil, spp_locale: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 64
|
Instance Attribute Details
#back ⇒ Integer?
The number of days back to fetch observations.
32 |
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 32 optional :back, Integer |
#dist ⇒ Integer?
Only fetch observations within this distance of the provided lat/lng
38 |
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 38 optional :dist, Integer |
#hotspot ⇒ Boolean?
Only fetch observations from hotspots
44 |
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 44 optional :hotspot, Phoebe::Internal::Type::Boolean |
#include_provisional ⇒ Boolean?
Include observations which have not yet been reviewed.
50 |
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 50 optional :include_provisional, Phoebe::Internal::Type::Boolean |
#lat ⇒ Float
21 |
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 21 required :lat, Float |
#lng ⇒ Float
26 |
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 26 required :lng, Float |
#max_results ⇒ Integer?
Only fetch up to this number of observations
56 |
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 56 optional :max_results, Integer |
#species_code ⇒ String
16 |
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 16 required :species_code, String |
#spp_locale ⇒ String?
Use this language for species common names
62 |
# File 'lib/phoebe/models/data/observations/nearest/geo_specie_list_params.rb', line 62 optional :spp_locale, String |