Class: Phoebe::Resources::Data::Observations::Nearest
- Inherits:
-
Object
- Object
- Phoebe::Resources::Data::Observations::Nearest
- Defined in:
- lib/phoebe/resources/data/observations/nearest.rb,
lib/phoebe/resources/data/observations/nearest/geo_species.rb
Defined Under Namespace
Classes: GeoSpecies
Instance Attribute Summary collapse
-
#geo_species ⇒ Phoebe::Resources::Data::Observations::Nearest::GeoSpecies
readonly
The data/obs end-points are used to fetch observations submitted to eBird in checklists.
Instance Method Summary collapse
-
#initialize(client:) ⇒ Nearest
constructor
private
A new instance of Nearest.
Constructor Details
#initialize(client:) ⇒ Nearest
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Nearest.
19 20 21 22 |
# File 'lib/phoebe/resources/data/observations/nearest.rb', line 19 def initialize(client:) @client = client @geo_species = Phoebe::Resources::Data::Observations::Nearest::GeoSpecies.new(client: client) end |
Instance Attribute Details
#geo_species ⇒ Phoebe::Resources::Data::Observations::Nearest::GeoSpecies (readonly)
The data/obs end-points are used to fetch observations submitted to eBird in checklists. There are two categories of end-point: 1. Fetch observations for a specific country, region or location. 2. Fetch observations for nearby locations - up to a distance of 50km. Each end-point supports optional query parameters which allow you to filter the list of observations returned.
14 15 16 |
# File 'lib/phoebe/resources/data/observations/nearest.rb', line 14 def geo_species @geo_species end |