Class: Phoebe::Resources::Product::Checklist
- Inherits:
-
Object
- Object
- Phoebe::Resources::Product::Checklist
- Defined in:
- lib/phoebe/resources/product/checklist.rb
Overview
The product end-points make it easy to get the information shown in various pages on the eBird web site: 1. The Top 100 contributors on a given date. 2. The checklists submitted on a given date. 3. The most recent checklists submitted. 4. A summary of the checklists submitted on a given date. 5. The details and all the observations of a checklist.
Instance Method Summary collapse
-
#initialize(client:) ⇒ Checklist
constructor
private
A new instance of Checklist.
-
#view(sub_id, request_options: {}) ⇒ Phoebe::Models::Product::ChecklistViewResponse
Get the details and observations of a checklist.
Constructor Details
#initialize(client:) ⇒ Checklist
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Checklist.
37 38 39 |
# File 'lib/phoebe/resources/product/checklist.rb', line 37 def initialize(client:) @client = client end |
Instance Method Details
#view(sub_id, request_options: {}) ⇒ Phoebe::Models::Product::ChecklistViewResponse
Get the details and observations of a checklist.
#### Notes Do NOT use this to download large amounts of data. You will be banned if you do. In the fields for each observation, the following fields are duplicates or obsolete and will be removed at a future date: howManyAtleast, howManyAtmost, hideFlags, projId, subId, subnational1Code and present.
25 26 27 28 29 30 31 32 |
# File 'lib/phoebe/resources/product/checklist.rb', line 25 def view(sub_id, params = {}) @client.request( method: :get, path: ["product/checklist/view/%1$s", sub_id], model: Phoebe::Models::Product::ChecklistViewResponse, options: params[:request_options] ) end |