Class: Phoebe::Resources::Ref::Taxonomy::Forms
- Inherits:
-
Object
- Object
- Phoebe::Resources::Ref::Taxonomy::Forms
- Defined in:
- lib/phoebe/resources/ref/taxonomy/forms.rb
Instance Method Summary collapse
-
#initialize(client:) ⇒ Forms
constructor
private
A new instance of Forms.
-
#list(species_code, request_options: {}) ⇒ Array<String>
For a species, get the list of subspecies recognised in the taxonomy.
Constructor Details
#initialize(client:) ⇒ Forms
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Forms.
32 33 34 |
# File 'lib/phoebe/resources/ref/taxonomy/forms.rb', line 32 def initialize(client:) @client = client end |
Instance Method Details
#list(species_code, request_options: {}) ⇒ Array<String>
For a species, get the list of subspecies recognised in the taxonomy. The results include the species that was passed in.
20 21 22 23 24 25 26 27 |
# File 'lib/phoebe/resources/ref/taxonomy/forms.rb', line 20 def list(species_code, params = {}) @client.request( method: :get, path: ["ref/taxon/forms/%1$s", species_code], model: Phoebe::Internal::Type::ArrayOf[String], options: params[:request_options] ) end |