Class: Phoebe::Resources::Ref::Taxonomy::Versions
- Inherits:
-
Object
- Object
- Phoebe::Resources::Ref::Taxonomy::Versions
- Defined in:
- lib/phoebe/resources/ref/taxonomy/versions.rb
Instance Method Summary collapse
-
#initialize(client:) ⇒ Versions
constructor
private
A new instance of Versions.
-
#list(request_options: {}) ⇒ Array<Phoebe::Models::Ref::Taxonomy::VersionListResponseItem>
Returns a list of all versions of the taxonomy, with a flag indicating which is the latest.
Constructor Details
#initialize(client:) ⇒ Versions
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Versions.
30 31 32 |
# File 'lib/phoebe/resources/ref/taxonomy/versions.rb', line 30 def initialize(client:) @client = client end |
Instance Method Details
#list(request_options: {}) ⇒ Array<Phoebe::Models::Ref::Taxonomy::VersionListResponseItem>
Returns a list of all versions of the taxonomy, with a flag indicating which is the latest.
18 19 20 21 22 23 24 25 |
# File 'lib/phoebe/resources/ref/taxonomy/versions.rb', line 18 def list(params = {}) @client.request( method: :get, path: "ref/taxonomy/versions", model: Phoebe::Internal::Type::ArrayOf[Phoebe::Models::Ref::Taxonomy::VersionListResponseItem], options: params[:request_options] ) end |